/*
 * Copyright 2007 Geir Hedemark
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.testaco.test;

import java.io.StringWriter;

import org.dbunit.dataset.DataSetException;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.xml.XmlDataSetWriter;

public class ComparisonResult {
	public IDataSet content;
	public IDataSet expected;
	public String tableName;
	public String resultSetFilename;
	public String databaseKey;
	
	public ComparisonResult(ComparisonResult result) {
		this.content = result.content;
		this.expected = result.expected;
		this.tableName = result.tableName;
		this.resultSetFilename = result.resultSetFilename;
		this.databaseKey = result.databaseKey;
	}

	public ComparisonResult() {
	}

	public String toString(Throwable e) {
		StringBuilder message = new StringBuilder();
		message.append("Database:\"");
		message.append(databaseKey);
		message.append("\",Table:\"");
		message.append(tableName);
		message.append("\",Resultsetfile:\"");
		message.append(resultSetFilename);
		message.append("\",Message:\"");
		if (e != null) {
  		   message.append(e.getMessage());
		}
		message.append("\",Xmldump:\"");
		if (content != null) {
			StringWriter sw = new StringWriter();
			XmlDataSetWriter wr = new XmlDataSetWriter(sw);
			try {
				wr.write(content);
			} catch (DataSetException e1) {
				//Hope this never happens...
			}
			message.append(sw.toString());
			message.append("\"");
		}
		return message.toString();
	}
	public String toString() {
		return toString(null);
	}
}
