/*
 * Copyright 2007 Geir Hedemark
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.testaco.test.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation checks the current contents of a database against a reference DBUnit data set after a test has completed.
 * <p/>
 * The annotation takes two parameters. One is mandatory, and points to a DBUnit-format data set that is to be loaded. The other
 * parameter selects the database to use, and has the value "default" if not explicitly specified.
 * <p/>
 * The annotation has an interface with the Testaco Eclipse plugin. If an error is found during processing related to this
 * annotation, the exceptions that are thrown will have a format that is parsable by the plugin. This allows the plugin
 * to trigger functionality to remedy the problem.
 * 
 * @see org.testaco.test.SpringIntegrationTestCase
 * @see org.testaco.test.DatabaseTestSuite
 * 
 * @author geir
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public abstract @interface CheckDb {
	String database() default "default";
	String datafile();
}
